# Generated by Django 2.2.4 on 2019-08-29 14:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("options", "0003_auto_20190827_0605")]

    operations = [
        migrations.AddField(
            model_name="option",
            name="is_public",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="useroption",
            name="is_public",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="option",
            name="public_name",
            field=models.CharField(
                blank=True,
                db_index=True,
                max_length=255,
                verbose_name="public name of the parameter",
            ),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="name",
            field=models.CharField(max_length=255, verbose_name="parameter name"),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="public_name",
            field=models.CharField(
                blank=True,
                db_index=True,
                max_length=255,
                verbose_name="public name of the parameter",
            ),
        ),
    ]



from django.utils.translation import ugettext_lazy as _

FLOAT, INT, STR, FILE = (0, 1, 2, 3)
TYPE_CHOICES = (
    (FLOAT, _("Float")),
    (INT, _("Integer")),
    (STR, _("String")),
    (FILE, _("File")),
)
CONVERTER = {INT: int, FLOAT: float, STR: str, FILE: str}



from django.db import models

from options import get_option_model
from options.settings import DEFAULT_EXCLUDE_USER


class OptionQuerySet(models.QuerySet):
    def public(self):
        """Gets public options."""
        return self.filter(is_public=True)


class OptionManager(models.Manager):
    """Manager for options."""

    def get_queryset(self):
        return OptionQuerySet(self.model, using=self._db)

    def public(self):
        """Gets public options."""
        return self.get_queryset().public()

    def get_value(self, name, default=None):
        """Gets the value with the proper type."""
        try:
            option = self.model.objects.get(name=name)
            return option.get_value()
        except self.model.DoesNotExist:
            return default


class UserOptionQuerySet(models.QuerySet):
    def public(self):
        """Gets public options."""
        return self.filter(is_public=True)


class UserOptionManager(models.Manager):
    """Manager to handle user's custom options."""

    def get_queryset(self):
        return OptionQuerySet(self.model, using=self._db)

    def public(self):
        """Gets public options."""
        return self.get_queryset().public()

    def filter_user_customizable(self):
        """Returns option that the user can customize himself."""
        return self.exclude(name__in=DEFAULT_EXCLUDE_USER)

    def get_value(self, name, user=None, default=None):
        """Gets the value with the proper type."""
        Option = get_option_model()

        if user is None:
            return Option.objects.get_value(name=name, default=default)
        try:
            option = self.model.objects.get(user=user, name=name)
            return option.get_value()
        except self.model.DoesNotExist:
            return Option.objects.get_value(name=name, default=default)



# Generated by Django 2.1 on 2018-10-02 07:54

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("options", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="UserOption",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "public_name",
                    models.CharField(
                        db_index=True,
                        max_length=255,
                        verbose_name="Public name of the parameter",
                    ),
                ),
                (
                    "type",
                    models.PositiveIntegerField(
                        choices=[(0, "Float"), (1, "Integer"), (2, "String")], default=2
                    ),
                ),
                (
                    "value",
                    models.CharField(
                        blank=True,
                        default=None,
                        max_length=256,
                        null=True,
                        verbose_name="Value",
                    ),
                ),
                ("is_list", models.BooleanField(default=False)),
                ("name", models.CharField(max_length=255, verbose_name="Parameter")),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="options",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={"ordering": ["public_name"]},
        ),
        migrations.AlterModelOptions(
            name="option", options={"ordering": ["public_name"]}
        ),
        migrations.AlterUniqueTogether(
            name="useroption", unique_together={("user", "name")}
        ),
    ]



import json

from django.core.management import BaseCommand

from options.models import Option


class Command(BaseCommand):
    help = "Export current options to JSON format."

    def handle(self, *args, **options):
        export = dict()
        for option in Option.objects.all():
            export[option.name] = {
                "value": option.value,
                "type": option.type,
                "public_name": option.public_name,
            }
        self.stdout.write(json.dumps(export, indent=4, sort_keys=True))



import hashlib
import os
import random
import time

from django.apps import apps as django_apps
from django.core.exceptions import ImproperlyConfigured
from django.utils.deconstruct import deconstructible
from django.utils.text import slugify

from options.constants import INT, FLOAT, STR, CONVERTER


def get_option_model():
    """Return the Notification model that is active in this project."""
    from options.settings import DEFAULT_OPTION_MODEL

    try:
        return django_apps.get_model(DEFAULT_OPTION_MODEL, require_ready=False)
    except ValueError:
        raise ImproperlyConfigured(
            "SIMPLE_OPTIONS_OPTION_MODEL must be of the form 'app_label.model_name'"
        )
    except LookupError:
        raise ImproperlyConfigured(
            "SIMPLE_OPTIONS_OPTION_MODEL refers to model '%s' that has not "
            "been installed" % DEFAULT_OPTION_MODEL
        )


def get_user_option_model():
    """Return the Notification model that is active in this project."""
    from options.settings import DEFAULT_USER_OPTION_MODEL

    try:
        return django_apps.get_model(DEFAULT_USER_OPTION_MODEL, require_ready=False)
    except ValueError:
        raise ImproperlyConfigured(
            "SIMPLE_OPTIONS_USER_OPTION_MODEL must be of the form "
            "'app_label.model_name'"
        )
    except LookupError:
        raise ImproperlyConfigured(
            "SIMPLE_OPTIONS_USER_OPTION_MODEL refers to model '%s' that has not "
            "been installed" % DEFAULT_USER_OPTION_MODEL
        )


def convert_value(value, value_type):
    """Converts the given value to the given type."""
    default_values = {INT: 0, FLOAT: 1.0, STR: ""}
    try:
        option_value = CONVERTER.get(value_type, str)(value)
    except ValueError:
        option_value = default_values.get(value_type)
    return option_value


@deconstructible
class UploadToDir(object):
    """Generates a function to give  to ``upload_to`` parameter in
    models.Fields, that generates an name for uploaded files based on ``populate_from``
    attribute.
    """

    def __init__(self, path, populate_from=None, prefix=None, random_name=False):
        self.path = path
        self.populate_from = populate_from
        self.random_name = random_name
        self.prefix = prefix

    def __call__(self, instance, filename):
        """Generates an name for an uploaded file."""
        if self.populate_from is not None and not hasattr(instance, self.populate_from):
            raise AttributeError(
                "Instance hasn't {} attribute".format(self.populate_from)
            )
        ext = filename.split(".")[-1]
        readable_name = slugify(filename.split(".")[0])
        if self.populate_from:
            readable_name = slugify(getattr(instance, self.populate_from))
        if self.random_name:
            random_name = hashlib.sha256(
                "{}--{}".format(time.time(), random.random()).encode("utf-8")
            )
            readable_name = random_name.hexdigest()
        elif self.prefix is not None:
            readable_name = f"{self.prefix}{readable_name}"
        file_name = "{}.{}".format(readable_name, ext)
        return os.path.join(self.path, file_name)



from django.utils.translation import ugettext_lazy as _
from rest_framework import serializers

from options import get_option_model, get_user_option_model
from options.settings import DEFAULT_EXCLUDE_USER

Option = get_option_model()
UserOption = get_user_option_model()


class OptionSerializer(serializers.ModelSerializer):
    class Meta:
        model = Option
        fields = [
            "id",
            "name",
            "public_name",
            "type",
            "value",
            "file",
            "is_list",
            "is_public",
        ]


class UserOptionSerializer(OptionSerializer):

    is_public = serializers.BooleanField(default=True, write_only=True)

    class Meta(OptionSerializer.Meta):
        model = UserOption

    def validate_name(self, value):
        """Checks if the name is in DEFAULT_EXCLUDE_USER_OPTIONS."""
        if value in DEFAULT_EXCLUDE_USER:
            raise serializers.ValidationError(
                _("The name in the option can't be handle by the user.")
            )
        return value



from django.urls import include, path
from rest_framework import routers

from options.rest_framework.viewsets import OptionViewSet, UserOptionViewSet


app_name = "api"

router = routers.DefaultRouter()
router.register("options", viewset=OptionViewSet)
router.register("user-options", viewset=UserOptionViewSet)

urlpatterns = [path("", include(router.urls))]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-23 15:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Option",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        max_length=255,
                        unique=True,
                        verbose_name="Parameter",
                    ),
                ),
                (
                    "public_name",
                    models.CharField(
                        db_index=True,
                        max_length=255,
                        verbose_name="Public name of the parameter",
                    ),
                ),
                (
                    "type",
                    models.PositiveIntegerField(
                        choices=[(0, "Float"), (1, "Integer"), (2, "String")], default=2
                    ),
                ),
                (
                    "value",
                    models.CharField(
                        blank=True,
                        default=None,
                        max_length=256,
                        null=True,
                        verbose_name="Value",
                    ),
                ),
                ("is_list", models.BooleanField(default=False)),
            ],
        )
    ]



from django.test import TestCase
from rest_framework import status
from rest_framework.test import APITestCase

from options import INT, FLOAT, STR
from options.models import Option, UserOption
from tests.factories import UserFactory, UserOptionFactory, OptionFactory


class OptionTests(TestCase):
    def test_default_options(self):
        value = Option.objects.get_value("default_option", default="other")
        self.assertEqual("default", value)

    def test_int_conversion_options(self):
        name = "int_option"
        OptionFactory(name=name, value="42", type=INT)
        value = Option.objects.get_value(name)
        self.assertIsInstance(value, int)
        self.assertEqual(42, value)

    def test_str_conversion_options(self):
        name = "string_option"
        OptionFactory(name=name, value="42")
        value = Option.objects.get_value(name)
        self.assertIsInstance(value, str)
        self.assertEqual("42", value)

    def test_float_conversion_options(self):
        name = "string_option"
        OptionFactory(name=name, value="42.5", type=FLOAT)
        value = Option.objects.get_value(name)
        self.assertIsInstance(value, float)
        self.assertAlmostEqual(42.5, value)

    def test_public(self):
        options = OptionFactory.create_batch(size=5, is_public=True)
        OptionFactory.create_batch(size=3, is_public=False)
        self.assertEqual(len(options), Option.objects.public().count())


class UserOptionTests(TestCase):
    def test_custom_user_options(self):
        user = UserFactory()
        name = "default_option"
        expected_value = "user default"
        UserOption.objects.create(
            name=name, public_name=name, value=expected_value, type=STR, user=user
        )
        value = UserOption.objects.get_value(name, user=user, default="other")
        self.assertEqual(expected_value, value)


class OptionAPITests(APITestCase):
    def test_list_options(self):
        options = OptionFactory.create_batch(size=10)
        admin = UserFactory(is_staff=True)
        self.client.force_authenticate(admin)
        response = self.client.get("/api/options/", format="json")
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        data = response.json()
        self.assertEqual(1 + len(options), len(data))

    def test_list_options_no_staff(self):
        OptionFactory.create_batch(size=10)
        options = OptionFactory.create_batch(size=3, is_public=True)
        admin = UserFactory()
        self.client.force_authenticate(admin)
        response = self.client.get("/api/options/", format="json")
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        data = response.json()
        self.assertEqual(len(options), len(data))

    def test_cant_update_options_no_staff(self):
        OptionFactory.create_batch(size=10)
        options = OptionFactory.create_batch(size=3, is_public=True)
        admin = UserFactory()
        self.client.force_authenticate(admin)
        data = {"value": "dummy"}
        response = self.client.patch(
            f"/api/options/{options[0].pk}/", data=data, format="json"
        )
        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)

    def test_can_update_options_staff(self):
        OptionFactory.create_batch(size=10)
        options = OptionFactory.create_batch(size=3, is_public=True)
        admin = UserFactory(is_staff=True)
        self.client.force_authenticate(admin)
        data = {"value": "dummy"}
        response = self.client.patch(
            f"/api/options/{options[0].pk}/", data=data, format="json"
        )
        self.assertEqual(response.status_code, status.HTTP_200_OK)

    def test_list_user_options(self):
        user = UserFactory()
        name = "default_option"
        expected_value = "user default"
        UserOptionFactory(name=name, value=expected_value, user=user, is_public=True)
        self.client.force_authenticate(user)
        response = self.client.get("/api/user-options/", format="json")
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        data = response.json()
        self.assertEqual(1, len(data))

    def test_list_user_options_with_exclude(self):
        user = UserFactory()
        name = "default_option"
        expected_value = "user default"
        UserOptionFactory(
            name="secret_option", value="secret", user=user, is_public=True
        )
        UserOptionFactory(name=name, value=expected_value, user=user, is_public=True)
        self.client.force_authenticate(user)
        response = self.client.get("/api/user-options/", format="json")
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        data = response.json()
        self.assertEqual(1, len(data))

    def test_create_user_options(self):
        user = UserFactory()
        name = "default_option"
        expected_value = "user default"
        data = {"name": name, "value": expected_value}
        self.client.force_authenticate(user)
        response = self.client.post("/api/user-options/", data=data, format="json")
        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
        self.assertEqual(1, UserOption.objects.filter(user=user).count())

    def test_create_user_options_excluded(self):
        user = UserFactory()
        name = "secret_option"
        expected_value = "secret"
        data = {"name": name, "value": expected_value}
        self.client.force_authenticate(user)
        response = self.client.post("/api/user-options/", data=data, format="json")
        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)



from options.models import Option


def options(request):
    """Context processor that adds options to the template context."""
    return {option.name: option.get_value() for option in Option.objects.all()}



import logging

from django.apps import AppConfig
from django.db.models.signals import post_migrate
from django.db.utils import IntegrityError
from django.utils.translation import ugettext_lazy as _

from options import get_option_model
from options.settings import DEFAULT_CONFIGURATION

logger = logging.getLogger(__name__)


def create_default_options(sender, **kwargs):
    """Creates the defaults configuration options if they don't exists."""
    Option = get_option_model()

    for key, data in DEFAULT_CONFIGURATION.items():
        if not Option.objects.filter(name=key).exists():
            try:
                Option.objects.create(name=key, **data)
            except IntegrityError:
                logger.warning("Option '%s' already installed" % key)


class ConfigurationsConfig(AppConfig):
    name = "options"
    verbose_name = _("Options")

    def ready(self):
        """Connects signals with their managers."""
        post_migrate.connect(create_default_options)



from django.conf import settings

# Needed to build and publish with Flit
# ------------------------------------------------------------------------------
SECRET_KEY = "snitch"

# Specific project configuration
# ------------------------------------------------------------------------------
# Set on settings the default options for this project. These will be created
# on the post migrate signal handler.
# Sample:
#
# SIMPLE_OPTIONS_CONFIGURATION = {
#     "sold_out": {
#         "value": 0,
#         "type": INT,
#         "public_name": "Sets tickets as sold out"
#     },
# }
#
DEFAULT_CONFIGURATION = getattr(settings, "SIMPLE_OPTIONS_CONFIGURATION", {})

# Set the list of options that the user can't customize.
DEFAULT_EXCLUDE_USER = getattr(settings, "SIMPLE_OPTIONS_EXCLUDE_USER", tuple())

# Swappable Option model
DEFAULT_OPTION_MODEL = getattr(
    settings, "SIMPLE_OPTIONS_OPTION_MODEL", "options.Option"
)

# Swappable UserOption model
DEFAULT_USER_OPTION_MODEL = getattr(
    settings, "SIMPLE_OPTIONS_USER_OPTION_MODEL", "options.UserOption"
)



from rest_framework import permissions
from rest_framework.permissions import SAFE_METHODS


class IsAdminForNoSafeMethods(permissions.BasePermission):
    def has_permission(self, request, view):
        if request.method not in SAFE_METHODS:
            return request.user.is_authenticated and request.user.is_staff
        return True



"""Simple app to add configuration options to a Django project."""
from options.constants import FLOAT, INT, STR, FILE, TYPE_CHOICES, CONVERTER
from options.helpers import get_option_model, get_user_option_model

default_app_config = "options.apps.ConfigurationsConfig"

__all__ = [
    "get_option_model",
    "get_user_option_model",
    "FLOAT",
    "INT",
    "STR",
    "FILE",
    "TYPE_CHOICES",
    "CONVERTER",
]
__version__ = "2.1.1"



# Generated by Django 2.2.4 on 2019-08-27 11:05

from django.db import migrations, models
import options.helpers


class Migration(migrations.Migration):

    dependencies = [("options", "0002_auto_20181002_0254")]

    operations = [
        migrations.AddField(
            model_name="option",
            name="file",
            field=models.FileField(
                blank=True,
                null=True,
                upload_to=options.helpers.UploadToDir("options", random_name=True),
            ),
        ),
        migrations.AddField(
            model_name="useroption",
            name="file",
            field=models.FileField(
                blank=True,
                null=True,
                upload_to=options.helpers.UploadToDir("options", random_name=True),
            ),
        ),
        migrations.AlterField(
            model_name="option",
            name="name",
            field=models.CharField(
                db_index=True,
                max_length=255,
                unique=True,
                verbose_name="parameter name",
            ),
        ),
        migrations.AlterField(
            model_name="option",
            name="public_name",
            field=models.CharField(
                db_index=True,
                max_length=255,
                verbose_name="public name of the parameter",
            ),
        ),
        migrations.AlterField(
            model_name="option",
            name="type",
            field=models.PositiveIntegerField(
                choices=[(0, "Float"), (1, "Integer"), (2, "String"), (3, "File")],
                default=2,
            ),
        ),
        migrations.AlterField(
            model_name="option",
            name="value",
            field=models.CharField(
                blank=True,
                default=None,
                max_length=256,
                null=True,
                verbose_name="value",
            ),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="public_name",
            field=models.CharField(
                db_index=True,
                max_length=255,
                verbose_name="public name of the parameter",
            ),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="type",
            field=models.PositiveIntegerField(
                choices=[(0, "Float"), (1, "Integer"), (2, "String"), (3, "File")],
                default=2,
            ),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="value",
            field=models.CharField(
                blank=True,
                default=None,
                max_length=256,
                null=True,
                verbose_name="value",
            ),
        ),
    ]



from rest_framework import viewsets
from rest_framework.permissions import IsAuthenticated

from options import get_option_model, get_user_option_model
from options.rest_framework.permissions import IsAdminForNoSafeMethods
from options.rest_framework.serializers import OptionSerializer, UserOptionSerializer

Option = get_option_model()
UserOption = get_user_option_model()


class OptionViewSet(viewsets.ModelViewSet):
    queryset = Option.objects.all()
    serializer_class = OptionSerializer
    permission_classes = (IsAdminForNoSafeMethods,)

    def get_queryset(self):
        queryset = super().get_queryset()
        if self.request.user.is_authenticated and self.request.user.is_staff:
            return queryset
        return queryset.public()


class UserOptionViewSet(viewsets.ModelViewSet):
    queryset = UserOption.objects.filter_user_customizable()
    serializer_class = UserOptionSerializer
    permission_classes = (IsAuthenticated,)

    def get_queryset(self):
        queryset = super().get_queryset()
        if self.request.user.is_authenticated and self.request.user.is_staff:
            return queryset
        return queryset.public().filter(user=self.request.user)

    def perform_create(self, serializer):
        serializer.save(user=self.request.user)



import django

DEBUG = True
USE_TZ = True

SECRET_KEY = "dummy"

DATABASES = {"default": {"ENGINE": "django.db.backends.sqlite3", "NAME": ":memory:"}}

ROOT_URLCONF = "tests.urls"

INSTALLED_APPS = [
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sites",
    "options",
]

SITE_ID = 1

if django.VERSION >= (1, 10):
    MIDDLEWARE = ()
else:
    MIDDLEWARE_CLASSES = ()

INSTALLED_APPS += ("rest_framework", "rest_framework.authtoken")
REST_FRAMEWORK = {
    "DEFAULT_AUTHENTICATION_CLASSES": (
        "rest_framework.authentication.TokenAuthentication",
        "rest_framework.authentication.SessionAuthentication",
    )
}
from options.constants import STR

SIMPLE_OPTIONS_CONFIGURATION = {
    "default_option": {
        "public_name": "Default Option",
        "type": STR,
        "value": "default",
    }
}
SIMPLE_OPTIONS_EXCLUDE_USER = ["secret_option"]



from django.contrib import admin

from options.models import Option, UserOption


@admin.register(Option)
class OptionAdmin(admin.ModelAdmin):
    """Manage configuration options."""

    list_display = ["public_name", "value", "is_public"]
    list_filter = ["is_public"]
    search_fields = ["public_name", "name"]


@admin.register(UserOption)
class UserOptionAdmin(admin.ModelAdmin):
    """Manage configuration user options."""

    list_display = ["user", "public_name", "value", "is_public"]
    list_filter = ["is_public"]
    search_fields = ["public_name", "name"]



from django.conf import settings
from django.core.exceptions import ValidationError
from django.db import models
from django.utils.translation import ugettext_lazy as _

from options.constants import STR, TYPE_CHOICES, CONVERTER, FILE
from options.helpers import convert_value, UploadToDir
from options.managers import OptionManager, UserOptionManager


class BaseOption(models.Model):
    """Base model for system options and configurations."""

    name = models.CharField(
        verbose_name=_("parameter name"), max_length=255, unique=True, db_index=True
    )
    public_name = models.CharField(
        verbose_name=_("public name of the parameter"),
        max_length=255,
        unique=False,
        blank=True,
        db_index=True,
    )
    type = models.PositiveIntegerField(choices=TYPE_CHOICES, default=STR)
    value = models.CharField(
        null=True, blank=True, default=None, max_length=256, verbose_name=_("value")
    )
    file = models.FileField(
        upload_to=UploadToDir("options", random_name=True), null=True, blank=True
    )
    is_list = models.BooleanField(default=False)
    is_public = models.BooleanField(default=False)

    class Meta:
        abstract = True

    def __str__(self):
        return f"{self.public_name}"

    def get_value(self):
        """Gets the value with the proper type. If the type is not
        valid it would return the default value for the field, to avoid
        problems with manual database modifications.
        """
        # If the option is a file, returns the URL of the file
        if self.type == FILE and self.file is not None:
            return self.file.url
        if not self.is_list:
            return convert_value(self.value, self.type)
        else:
            values = self.value.split(",")
            return [convert_value(type, value) for value in values]

    def clean(self):
        """Calls to the converter to check the type conversion. Added exception
        for lists, to check all values.
        """
        try:
            values = [self.value] if not self.is_list else self.value.split(",")
            [CONVERTER.get(self.type, str)(value) for value in values]
        except ValueError:
            raise ValidationError(_("Invalid value for this type."))
        # Default public name
        if not self.public_name:
            self.public_name = self.name

    def save(self, *args, **kwargs):
        self.clean()
        super().save(*args, **kwargs)


class Option(BaseOption):
    """System options and configurations."""

    objects = OptionManager()

    class Meta:
        ordering = ["public_name"]
        swappable = "SIMPLE_OPTIONS_OPTION_MODEL"


class UserOption(BaseOption):
    """Custom option for a user."""

    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, related_name="options", on_delete=models.CASCADE
    )
    name = models.CharField(_("parameter name"), max_length=255)

    objects = UserOptionManager()

    class Meta:
        unique_together = ["user", "name"]
        ordering = ["public_name"]
        swappable = "SIMPLE_OPTIONS_USER_OPTION_MODEL"



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['options',
 'options.management',
 'options.management.commands',
 'options.migrations']

package_data = \
{'': ['*'], 'options': ['rest_framework/*']}

install_requires = \
['django']

extras_require = \
{'doc': ['sphinx'],
 'test': ['pytest', 'pytest-django', 'pytest-cov', 'factory_boy']}

setup(name='django-simple-options',
      version='2.1.1',
      description='Simple app to add configuration options to a Django project.',
      author='Marcos Gabarda',
      author_email='hey@marcosgabarda.com',
      url='https://github.com/marcosgabarda/django-simple-options',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
